@@ -1,7 +1,7 @@
 from django.test.html import Element, parse_html
 
 
-def contains_partial(haystack, needle):
+def contains_partial(haystack, needle, ignore_needle_children=False):
     """Search for a html element with at least the corresponding elements
     (other elements may be present in the matched element from the haystack)
     """
@@ -10,6 +10,13 @@ def contains_partial(haystack, needle):
     if not isinstance(needle, Element):
         needle = parse_html(needle)
 
+    if len(needle.children) > 0 and not ignore_needle_children:
+        raise NotImplementedError("contains_partial does not check needle's children:%s" % str(needle.children))
+
     if needle.name == haystack.name and set(needle.attributes).issubset(haystack.attributes):
         return True
-    return any(contains_partial(child, needle) for child in haystack.children if isinstance(child, Element))
+    return any(
+        contains_partial(child, needle, ignore_needle_children=ignore_needle_children)
+        for child in haystack.children
+        if isinstance(child, Element)
+    )
